# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['overreact', 'overreact.thermo']

package_data = \
{'': ['*']}

install_requires = \
['cclib>=1,<2', 'scipy>=1.10,<2.0']

extras_require = \
{'cli': ['rich>=13,<14'],
 'fast': ['jax>=0.4,<0.5', 'jaxlib>=0.4,<0.5'],
 'solvents': ['thermo>=0.2,<0.3']}

entry_points = \
{'console_scripts': ['overreact = overreact._cli:main']}

setup_kwargs = {
    'name': 'overreact',
    'version': '1.1.0',
    'description': '⚛️📈 Create and analyze chemical microkinetic models built from computational chemistry data',
    'long_description': '--- <!-- prettier-ignore -->\n\n<div align="center">\n<p>\n<a href="https://pypi.org/project/overreact/" >\n<img src="https://img.shields.io/pypi/v/overreact" alt="PyPI" />\n</a>\n<a href="https://pypi.org/project/overreact/" >\n<img src="https://img.shields.io/pypi/pyversions/overreact" alt="Python Versions" />\n</a>\n<a href="https://github.com/geem-lab/overreact/actions/workflows/python-package.yml" />\n<img src="https://github.com/geem-lab/overreact/actions/workflows/python-package.yml/badge.svg" alt="CI" />\n</a>\n<a href="https://codecov.io/gh/geem-lab/overreact" >\n<img src="https://codecov.io/gh/geem-lab/overreact/branch/main/graph/badge.svg?token=4WAVXCRXY8" alt="Coverage" />\n</a>\n<a href="https://github.com/geem-lab/overreact/blob/main/LICENSE">\n<img src="https://img.shields.io/github/license/geem-lab/overreact" alt="License" />\n</a>\n</p>\n<p>\n<a href="https://geem-lab.github.io/overreact-guide/">\n<img src="https://img.shields.io/badge/user%20guide-available-blue" alt="User guide" />\n</a>\n<a href="https://github.com/geem-lab/overreact/discussions">\n<img src="https://img.shields.io/github/discussions/geem-lab/overreact" alt="GitHub Discussions" />\n</a>\n<a href="https://github.com/geem-lab/overreact/issues">\n<img src="https://img.shields.io/github/issues-raw/geem-lab/overreact" alt="GitHub issues" />\n</a>\n</p>\n<p>\n<a href="https://pepy.tech/project/overreact" >\n<img src="https://pepy.tech/badge/overreact/month" alt="downloads/month" />\n</a>\n<a href="https://pepy.tech/project/overreact" >\n<img src="https://pepy.tech/badge/overreact" alt="total downloads" />\n</a>\n</p>\n<p>\n<a href="https://doi.org/10.1002/jcc.26861" >\n<img src="https://img.shields.io/badge/DOI-10.1002%2Fjcc.26861-blue" alt="DOI" />\n</a>\n<a href="https://doi.org/10.5281/zenodo.7504800">\n<img src="https://zenodo.org/badge/DOI/10.5281/zenodo.7504800.svg" alt="DOI" />\n</a>\n</p>\n<p>\n<a href="https://github.com/geem-lab/overreact#funding" >\n<img src="https://img.shields.io/badge/made%20in-Brazil-009c3b" alt="Made in Brazil 🇧🇷" />\n</a>\n</p>\n</div>\n\n<div align="center">\n<img alt="overreact" src="https://raw.githubusercontent.com/geem-lab/overreact-guide/master/logo.png" />\n</div>\n\n--- <!-- prettier-ignore -->\n\n**overreact** is a **library** and a **command-line tool** for building and\nanalyzing homogeneous **microkinetic models** from **first-principles\ncalculations**:\n\n```python\nIn [1]: from overreact import api  # the api\n\nIn [2]: api.get_k("S -> E‡ -> S",  # your model\n   ...:           {"S": "data/ethane/B97-3c/staggered.out",  # your data\n   ...:            "E‡": "data/ethane/B97-3c/eclipsed.out"})\nOut[2]: array([8.16880917e+10])  # your results\n```\n\nThe user specifies a set of\nelementary reactions that are believed to be relevant for the overall chemical\nphenomena. **overreact** offers a hopefully complete but simple environment for\nhypothesis testing in first-principles chemical kinetics.\n\n<details>\n    <summary style="cursor: pointer;">\n        🤔 What is <strong>microkinetic modeling</strong>?\n    </summary>\n    <p>\n        <strong>Microkinetic modeling</strong> is a technique used to predict the outcome\n        of complex chemical reactions.\n        It can be used\n        to investigate the catalytic transformations\n        of molecules.\n        <strong>overreact</strong> makes it easy to create\n        and analyze microkinetic models built\n        from computational chemistry data.\n    </p>\n</details>\n\n<br/>\n\n<details>\n    <summary style="cursor: pointer;">\n        🧐 What do you mean by <strong>first-principles calculations</strong>?\n    </summary>\n    <p>\n        We use the term <strong>first-principles calculations</strong> to refer to\n        calculations performed using quantum chemical modern methods such as\n        <a href="https://en.wikipedia.org/wiki/Hartree%E2%80%93Fock_method">Wavefunction</a>\n        and\n        <a href="https://en.wikipedia.org/wiki/Density_functional_theory">Density Functional</a>\n        theories.\n        For instance, the three-line example code above calculates the rate of methyl rotation in ethane (at\n        <a href="https://doi.org/10.1063/1.5012601">B97-3c</a>).\n        (Rather surprisingly, the error found is less than 2%\n        <a href="http://dx.doi.org/10.1126/science.1132178">when compared to available experimental results</a>.)\n    </p>\n</details>\n\n<br/>\n\n**overreact** uses **precise thermochemical partition funtions**, **tunneling\ncorrections** and data is **parsed directly** from computational chemistry\noutput files thanks to [`cclib`](https://cclib.github.io/) (see the\n[list of its supported programs](https://cclib.github.io/#summary)).\n\n## Installation\n\n**overreact** is a Python package, so you can easily install it with\n[`pip`](https://pypi.org/project/pip/):\n\n```console\n$ pip install "overreact[cli,fast]"\n```\n\nSee the\n[installation guide](https://geem-lab.github.io/overreact-guide/install.html)\nfor more details.\n\n> **🚀** **Where to go from here?** Take a look at the\n> [short introduction](https://geem-lab.github.io/overreact-guide/tutorial.html).\n> Or see\n> [below](https://geem-lab.github.io/overreact-guide/intro.html#where-to-go-next)\n> for more guidance.\n\n## Citing **overreact**\n\nIf you use **overreact** in your research, please cite:\n\n> Schneider, F. S. S.; Caramori, G. F.\n> _**Overreact**, an in Silico Lab: Automative Quantum Chemical Microkinetic Simulations for Complex Chemical Reactions_.\n> Journal of Computational Chemistry **2022**, 44 (3), 209–217.\n> [doi:10.1002/jcc.26861](https://doi.org/10.1002/jcc.26861).\n\nHere\'s the reference in [BibTeX](http://www.bibtex.org/) format:\n\n```bibtex\n@article{overreact_paper2022,\n  title         = {Overreact, an in silico lab: Automative quantum chemical microkinetic simulations for complex chemical reactions},\n  author        = {Schneider, Felipe S. S. and Caramori, Giovanni F.},\n  year          = {2022},\n  month         = {Apr},\n  journal       = {Journal of Computational Chemistry},\n  publisher     = {Wiley},\n  volume        = {44},\n  number        = {3},\n  pages         = {209–217},\n  doi           = {10.1002/jcc.26861},\n  issn          = {1096-987x},\n  url           = {http://dx.doi.org/10.1002/jcc.26861},\n}\n@software{overreact_software2021,\n  title         = {geem-lab/overreact: v1.1.0 \\vert{} Zenodo},\n  author        = {Felipe S. S. Schneider and Let\\\'{\\i}cia M. P. Madureira and  Giovanni F. Caramori},\n  year          = {2023},\n  month         = {Jan},\n  publisher     = {Zenodo},\n  doi           = {10.5281/zenodo.7504800},\n  url           = {https://doi.org/10.5281/zenodo.7504800},\n  version       = {v1.1.0},\n  howpublished  = {\\url{https://github.com/geem-lab/overreact}},\n}\n```\n\n## License\n\n**overreact** is open-source, released under the permissive **MIT license**. See\n[the LICENSE agreement](https://github.com/geem-lab/overreact/blob/main/LICENSE).\n\n## Funding\n\nThis project was developed at the [GEEM lab](https://geem-ufsc.org/)\n([Federal University of Santa Catarina](https://en.ufsc.br/), Brazil), and was\npartially funded by the\n[Brazilian National Council for Scientific and Technological Development (CNPq)](https://cnpq.br/),\ngrant number 140485/2017-1.\n',
    'author': 'Felipe S. S. Schneider',
    'author_email': 'schneider.felipe@posgrad.ufsc.br',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://geem-lab.github.io/overreact-guide/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<3.11',
}


setup(**setup_kwargs)
